@@ -17,7 +17,6 @@ from typing import List
 from .builders import AsyncResult
 from .queries import (
     MultiRefreshActionQuery,
-    MultiStartActionQuery,
     StartActionQuery,
 )
 
@@ -53,8 +52,7 @@ class ParallelExecutionCollector:
 
         assert len(self._queries) == len(self._async_results)
 
-        multi_query = MultiStartActionQuery(self._qctrl.gql_api, *self._queries)
-        response = multi_query()
+        response = [query() for query in self._queries]
 
         LOGGER.debug("response:%s", response)
 
@@ -65,7 +63,8 @@ class ParallelExecutionCollector:
 
         # update results with initial data
         for index, async_result in enumerate(self._async_results):
-            response_data = response[index]
+            mutation_name = self._queries[index]._mutation_name
+            response_data = response[index][mutation_name]
             async_result.update(self._qctrl.gql_env, response_data)
 
         # build refresh query
