@@ -172,14 +172,20 @@ def auth(oidc_url: str = DEFAULT_OIDC_URL, path: str = None) -> QctrlOAuth2Sessi
     help="Custom Q-CTRL API base URL.",
     show_default=f"{DEFAULT_API_ROOT}",
 )
+@click.option(
+    "--oidc-url",
+    default=DEFAULT_OIDC_URL,
+    help="Q-CTRL OIDC base URL.",
+    show_default=f"{DEFAULT_OIDC_URL}",
+)
 def activity(
-    options, limit, offset, status, type, api_root
+    options, limit, offset, status, type, api_root, oidc_url
 ):  # pylint: disable=redefined-builtin
     """
     Shows previously run actions and their statuses.
     """
     # Attempts to use previously store auth file, prompts interactive auth otherwise.
-    gql_api = create_gql_client(api_root, create_client_auth(api_root))
+    gql_api = create_gql_client(api_root, create_client_auth(oidc_url))
 
     activity_monitor = ActivityMonitorQuery(gql_api)
 
@@ -214,6 +220,12 @@ def version() -> None:
     help="Custom Q-CTRL API base URL.",
     show_default=f"{DEFAULT_API_ROOT}",
 )
+@click.option(
+    "--oidc-url",
+    default=DEFAULT_OIDC_URL,
+    help="Q-CTRL OIDC base URL.",
+    show_default=f"{DEFAULT_OIDC_URL}",
+)
 @click.option(
     "--type",
     help="specify the report type.",
@@ -221,11 +233,11 @@ def version() -> None:
     type=click.Choice(["queue", "worker"], case_sensitive=False),
     show_default="queue",
 )
-def env(api_root, type):  # pylint:disable=redefined-builtin
+def env(api_root, oidc_url, type):  # pylint:disable=redefined-builtin
     """Shows details to allow monitoring of the current
     environment.
     """
-    gql_api = create_gql_client(api_root, create_client_auth(api_root))
+    gql_api = create_gql_client(api_root, create_client_auth(oidc_url))
     if type and type == "worker":
         # display per-worker view
         get_env = GetWorkerInfoQuery(gql_api)
@@ -243,13 +255,19 @@ def env(api_root, type):  # pylint:disable=redefined-builtin
     help="Custom Q-CTRL API base URL.",
     show_default=f"{DEFAULT_API_ROOT}",
 )
+@click.option(
+    "--oidc-url",
+    default=DEFAULT_OIDC_URL,
+    help="Q-CTRL OIDC base URL.",
+    show_default=f"{DEFAULT_OIDC_URL}",
+)
 @click.option("--input", "--i", help="input graphql file", required=True)
 @click.option("--output", "--o", help="output file", default=None, show_default=None)
-def gql_query(api_root, input, output):  # pylint:disable=redefined-builtin
+def gql_query(api_root, oidc_url, input, output):  # pylint:disable=redefined-builtin
     """
     Runs gql query and return indented result.
     """
-    gql_api = create_gql_client(api_root, create_client_auth(api_root))
+    gql_api = create_gql_client(api_root, create_client_auth(oidc_url))
     with open(input, "r", encoding="utf-8") as file:
         query = file.read()
     result = gql_api.execute(gql(query))
