@@ -84,7 +84,7 @@ def _is_deprecated(field: Union[GraphQLField, GraphQLInputField]) -> bool:
     """
 
     if isinstance(field, GraphQLField):
-        return field.is_deprecated
+        return field.deprecation_reason is not None
 
     if isinstance(field, GraphQLInputField):
         return bool(re.search("deprecated", (field.description or "").lower()))
@@ -314,3 +314,39 @@ def error_handler(func: Callable) -> Any:
             raise QctrlException(UNIVERSAL_ERROR_MESSAGE) from exc
 
     return wrapper
+
+
+def print_environment_related_packages():
+    """
+    Prints the Python version being used, as well as
+    the versions of some loaded packages (external and from Q-CTRL).
+    """
+
+    modules = [
+        # External packages.
+        "jsonpickle",
+        "matplotlib",
+        "mloop",
+        "numpy",
+        "qiskit",
+        "qutip",
+        "scipy",
+        # Q-CTRL packages.
+        "qctrl",
+        "qctrlcommons",
+        "qctrlcore",
+        "qctrllocal",
+        "qctrlmloop",
+        "qctrlopencontrols",
+        "qctrlpyquil",
+        "qctrlqua",
+        "qctrltoolkit",
+        "qctrlvisualizer",
+    ]
+
+    py_version = sys.version_info
+    print(f"{'Python':20s}{py_version.major}.{py_version.minor}.{py_version.micro}")
+
+    for module_name in modules:
+        if module_name in sys.modules:
+            print(f"{module_name:20s}{sys.modules[module_name].__version__}")
